@@ -7,39 +7,40 @@ def processHeadings(doc: t.SpecT, scope: str = "doc") -> None:
     # scope arg can be "doc" or "all"
     # "doc" ignores things that are part of boilerplate
     for el in h.findAll("h2, h3, h4, h5, h6", doc):
-        h.addClass(el, "heading")
+        h.addClass(doc, el, "heading")
     headings = []
     for el in h.findAll(".heading:not(.settled)", doc):
         if scope == "doc" and h.treeAttr(el, "boilerplate"):
             continue
         headings.append(el)
     resetHeadings(headings)
-    determineHeadingLevels(headings)
+    determineHeadingLevels(doc, headings)
     addHeadingIds(doc, headings)
     addHeadingAlgorithms(headings)
     h.fixupIDs(doc, headings)
     addHeadingBonuses(headings)
     for el in headings:
-        h.addClass(el, "settled")
+        h.addClass(doc, el, "settled")
     if scope == "all" and doc.md.group in config.megaGroups["priv-sec"]:
         checkPrivacySecurityHeadings(h.findAll(".heading", doc))
 
 
-def resetHeadings(headings: t.List[t.ElementT]) -> None:
+def resetHeadings(headings: list[t.ElementT]) -> None:
     for header in headings:
         content = h.E.span({"class": "content"})
         h.moveContents(content, header)
         h.appendChild(header, content)
 
 
-def addHeadingIds(doc: t.SpecT, headings: t.List[t.ElementT]) -> None:
+def addHeadingIds(doc: t.SpecT, headings: list[t.ElementT]) -> None:
     neededIds = set()
     for header in headings:
         if header.get("id") is None:
             if header.get("data-dfn-type") is None:
                 # dfn headings will get their IDs assigned by the dfn code
                 neededIds.add(header)
-                id = config.simplifyText(h.textContent(h.find(".content", header)))
+                contentEl = t.cast("t.ElementT", h.find(".content", header))
+                id = config.simplifyText(h.textContent(contentEl))
                 header.set("id", h.safeID(doc, id))
     h.addOldIDs(headings)
     if len(neededIds) == 0:
@@ -54,11 +55,12 @@ def addHeadingIds(doc: t.SpecT, headings: t.List[t.ElementT]) -> None:
         )
 
 
-def checkPrivacySecurityHeadings(headings: t.List[t.ElementT]) -> None:
+def checkPrivacySecurityHeadings(headings: list[t.ElementT]) -> None:
     security = False
     privacy = False
     for header in headings:
-        text = h.textContent(h.find(".content", header)).lower()
+        contentEl = t.cast("t.ElementT", h.find(".content", header))
+        text = h.textContent(contentEl).lower()
         if "security" in text and "considerations" in text:
             security = True
         if "privacy" in text and "considerations" in text:
@@ -84,21 +86,21 @@ def checkPrivacySecurityHeadings(headings: t.List[t.ElementT]) -> None:
         )
 
 
-def addHeadingAlgorithms(headings: t.List[t.ElementT]) -> None:
+def addHeadingAlgorithms(headings: list[t.ElementT]) -> None:
     for header in headings:
         if header.get("data-algorithm") == "":
             header.set("data-algorithm", h.textContent(header).strip())
 
 
-def determineHeadingLevels(headings: t.List[t.ElementT]) -> None:
+def determineHeadingLevels(doc: t.SpecT, headings: list[t.ElementT]) -> None:
     headerLevel = [0, 0, 0, 0, 0]
 
-    def incrementLevel(level):
+    def incrementLevel(level: int) -> None:
         headerLevel[level - 2] += 1
         for i in range(level - 1, 5):
             headerLevel[i] = 0
 
-    def printLevel():
+    def printLevel() -> str:
         return ".".join(str(x) for x in headerLevel if x > 0)
 
     skipLevel = float("inf")
@@ -111,7 +113,7 @@ def determineHeadingLevels(headings: t.List[t.ElementT]) -> None:
             del header.attrib["data-level"]
 
         # If we encounter a no-num or an appendix, don't number it or any in the same section.
-        if h.hasClass(header, "no-num") or h.textContent(header).lstrip()[0:9].lower() == "appendix ":
+        if h.hasClass(doc, header, "no-num") or h.textContent(header).lstrip()[0:9].lower() == "appendix ":
             skipLevel = min(level, skipLevel)
             continue
         if skipLevel < level:
@@ -123,8 +125,9 @@ def determineHeadingLevels(headings: t.List[t.ElementT]) -> None:
         header.set("data-level", printLevel())
 
 
-def addHeadingBonuses(headings: t.List[t.ElementT]) -> None:
+def addHeadingBonuses(headings: list[t.ElementT]) -> None:
     for header in headings:
-        if header.get("data-level") is not None:
-            secno = h.E.span({"class": "secno"}, header.get("data-level") + ". ")
+        level = header.get("data-level")
+        if level is not None:
+            secno = h.E.span({"class": "secno"}, level + ". ")
             header.insert(0, secno)
