@@ -1,7 +1,11 @@
+from __future__ import annotations
+
 from . import oldShorthands
 
+from .. import t
 
-def run(doc):
+
+def run(doc: t.SpecT) -> None:
     oldShorthands.transformShorthandElements(doc)
     oldShorthands.transformProductionPlaceholders(doc)
     oldShorthands.transformMaybePlaceholders(doc)
